#!/bin/sh

#List of language code using RTL scripts
RTL_LANGS="he ps ar ur";

#Folder where to store the temporary files generated
#during the build process
BUILD_DIR="../tmp/${RELEASE}"

#Local folder to store LP branch containing exported translations
PO_EXPORT_DIR="${BUILD_DIR}/lp-l10n-branch"

#Make sure gettext tools produces the same output
export LANG=C

#text as it appers in pot file
title_en="Ubuntu Start Page";
search_en="Search";
help_en="Ubuntu help"
shop_en="Ubuntu shop"
community_en="Ubuntu community"
participate_en="Participate"

check_release(){
    index=0
    while [ "$index" -lt "${#template_files[*]}" ]
    do    # List all the elements in the array.
        if [ ! -e ${template_files[$index]} ]; then
            echo "Please put the English file at:"
            echo "    ${template_files[$index]}"
            exit
        fi
        let "index = $index + 1"
    done
}

get_translations(){
    rm -rf $PO_EXPORT_DIR
    echo " - Getting translations from ${L10N_BRANCH}"
    bzr co --lightweight $L10N_BRANCH $PO_EXPORT_DIR
}

translate_release(){

    #Make sure output dir for this release is clean

    index=0
    while [ "$index" -lt "${#template_files[*]}" ]
    do    # List all the elements in the array.
        translate_template ${template_files[$index]}
        let "index = $index + 1"
    done
}

translate_template() {

    template=$1
    echo " - Translating $template"

    # Remove non English files.
    # Temporary rename .en files to not be matched by '.*' .
    mv $template ${template%.en}
    rm ${template%.en}.*
    mv ${template%.en} $template

    # Iterate all langauges and create the translated index file.
    for po in ${PO_EXPORT_DIR}/po/*.po ;do

        # get lang name
        lang=${po##*/}
        lang=${lang%.po}

	if [ "$lang" == "en" ] ; then
	    # Don't translate .en pages.
	    continue
	fi

        # Ignore language if it has untranslated or fuzzy messages.
        msgfmt -o  /dev/null --statistics $po 2>&1 | \
            grep untranslated > /dev/null
        if [ $? = 0 ] ; then
            echo "   - Ignoring '$lang' as it is not complete."
            continue
        fi

        #init page
        output_page=${template%.en}.$lang
        cp $template ${output_page}

        #add html rtl attribute
        for rtl_lang in $RTL_LANGS ; do
            if [ $rtl_lang = $lang ] ; then
                sed -i -e "s/dir=\"ltr\"/dir=\"RTL\"/" ${output_page}
            fi
        done

        #add html lang attribute
        sed -i -e "s/lang=\"en\"/lang=\"$lang\"/" ${output_page}

        #translate page title
        title_po=`msggrep --no-wrap -K -e "$title_en" $po | \
            grep msgstr | grep -v "msgstr \"\"" | \
            sed -e 's/msgstr "\(.*\)"/\1/'`
        sed -i -e \
            "s/<title>$title_en<\/title>/<title>$title_po<\/title>/" \
            ${output_page}

        #translate hidden hl field
        #google wants ll-cc format, not ll_CC
        web_lang=`echo $lang | sed 's/\(.*\)/\L\1/;y/_/-/'`
        sed -i -e "s/name=\"hl\" value=\"en\"/name=\"hl\" value=\"$web_lang\"/" ${output_page}

        #translate search text
        search_po=`msggrep --no-wrap -K -e "$search_en" $po | \
            grep msgstr | grep -v "msgstr \"\"" | \
            sed -e 's/msgstr "\(.*\)"/\1/'`

        # Replace for Baidu and Yahoo Search button
        sed -i -e \
            "s/<button type=\"submit\">$search_en<\/button>/<button type=\"submit\">$search_po<\/button>/" \
            ${output_page}

        # Newer Google button layout
        sed -i -e \
            "s/<span class=\"acchide\">$search_en<\/span>/<span class=\"acchide\">$search_po<\/span>/" \
            ${output_page}

        #translate help text
        help_po=`msggrep --no-wrap -K -e "$help_en" $po | \
            grep msgstr | grep -v "msgstr \"\"" | \
            sed -e 's/msgstr "\(.*\)"/\1/'`
        sed -i -e "s/$help_en/$help_po/" ${output_page}

        #translate participate text
        community_po=`msggrep --no-wrap -K -e "$community_en" $po | \
            grep msgstr | grep -v "msgstr \"\"" | \
            sed -e 's/msgstr "\(.*\)"/\1/'`
        sed -i -e "s/$community_en/$community_po/" ${output_page}

        #translate shop text
        shop_po=`msggrep --no-wrap -K -e "$shop_en" $po | \
            grep msgstr | grep -v "msgstr \"\"" | \
            sed -e 's/msgstr "\(.*\)"/\1/'`
        sed -i -e "s/$shop_en/$shop_po/" ${output_page}

        # Rename polish and turkish files as they conflict with other
        # extensions recognized by the server
        # Rename lc_CC format to lc-CC.
        if [ $lang == "pl" ]; then
            mv ${output_page} ${template%.en}.po
        fi
        if [ $lang == "tr" ]; then
            mv ${output_page} ${template%.en}.tu
        fi
        if [[ $lang == *_* ]] ; then
    	    mv ${output_page} ${template%.en}.$web_lang
        fi

    done #get all po files
}


translate() {
    #Make sure we have the build folder
    mkdir -p ${BUILD_DIR}

    echo "Translating start page for Ubuntu ${RELEASE}"

    #Make sure we have the templates for this release
    check_release

    #Get latests translations from Launchpad
    get_translations

    #Generate translated files
    translate_release
}
